@@ -1,10 +1,10 @@
 /* mz_strm_buf.h -- Stream for buffering reads/writes
-   part of the MiniZip project
+   part of the minizip-ng project
 
    This version of ioapi is designed to buffer IO.
 
-   Copyright (C) 2010-2020 Nathan Moinvaziri
-      https://github.com/nmoinvaz/minizip
+   Copyright (C) Nathan Moinvaziri
+      https://github.com/zlib-ng/minizip-ng
 
    This program is distributed under the terms of the same license as zlib.
    See the accompanying LICENSE file for the full text of the license.
@@ -28,10 +28,10 @@ int32_t mz_stream_buffered_seek(void *stream, int64_t offset, int32_t origin);
 int32_t mz_stream_buffered_close(void *stream);
 int32_t mz_stream_buffered_error(void *stream);
 
-void*   mz_stream_buffered_create(void **stream);
-void    mz_stream_buffered_delete(void **stream);
+void *mz_stream_buffered_create(void);
+void mz_stream_buffered_delete(void **stream);
 
-void*   mz_stream_buffered_get_interface(void);
+void *mz_stream_buffered_get_interface(void);
 
 /***************************************************************************/
 
